<?php

/**
 * @file
 * Drush integration for ebt_slideshow.
 */

use Symfony\Component\Filesystem\Filesystem;

/**
 * The FlexSlider plugin URI.
 */
define('FLEXSLIDER_DOWNLOAD_URI', 'https://github.com/woocommerce/FlexSlider/archive/master.zip');
define('FLEXSLIDER_DOWNLOAD_PREFIX', 'flexslider-');

/**
 * Implements hook_drush_command().
 */
function ebt_slideshow_drush_command() {
  $items = [];

  // The key in the $items array is the name of the command.
  $items['flexslider-plugin'] = [
    'callback' => 'drush_flexslider_plugin',
    'description' => dt('Download and install the FlexSlider plugin.'),
     // No bootstrap.
    'bootstrap' => DRUSH_BOOTSTRAP_DRUSH,
    'arguments' => [
      'path' => dt('Optional. A path where to install the FlexSlider plugin. If omitted Drush will use the default location.'),
    ],
    'aliases' => ['flexsliderplugin'],
  ];

  return $items;
}

/**
 * Implements hook_drush_help().
 *
 * This function is called whenever a drush user calls
 * 'drush help <name-of-your-command>'
 */
function ebt_slideshow_drush_help($section) {
  switch ($section) {
    case 'drush:flexslider-plugin':
      return dt('Download and install the FlexSlider plugin from https://github.com/woocommerce/FlexSlider, default location is the libraries directory.');
  }
}

/**
 * Command to download the FlexSlider plugin.
 */
function drush_flexslider_plugin() {
  $args = func_get_args();
  if (!empty($args[0])) {
    $path = $args[0];
  }
  else {
    $path = 'libraries';
  }

  // Create the path if it does not exist.
  if (!is_dir($path)) {
    drush_op('mkdir', $path);
    \Drupal::logger(dt('Directory @path was created', ['@path' => $path]))->notice('notice');
  }

  // Set the directory to the download location.
  $olddir = getcwd();
  chdir($path);

  // Download the zip archive.
  if ($filepath = drush_download_file(FLEXSLIDER_DOWNLOAD_URI)) {
    $filename = basename($filepath);
    $dirname = FLEXSLIDER_DOWNLOAD_PREFIX . basename($filepath, '.zip');

    // Remove any existing FlexSlider plugin directory.
    if (is_dir($dirname) || is_dir('flexslider')) {
      Filesystem::remove($dirname, TRUE);
      Filesystem::remove('flexslider', TRUE);
      \Drupal::logger(dt('A existing FlexSlider plugin was deleted from @path', ['@path' => $path]))->notice('notice');
    }

    // Decompress the zip archive.
    drush_tarball_extract($filename);

    // Change the directory name to "flexslider" if needed.
    if ($dirname != 'flexslider') {
      drush_move_dir($dirname, 'flexslider', TRUE);
      $dirname = 'flexslider';
    }
  }

  if (is_dir($dirname)) {
    \Drupal::logger(dt('FlexSlider plugin has been installed in @path', ['@path' => $path]))->success('success');
  }
  else {
    \Drupal::logger(dt('Drush was unable to install the FlexSlider plugin to @path', ['@path' => $path]))->error('error');
  }

  // Set working directory back to the previous working directory.
  chdir($olddir);
}
